@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -30,7 +28,8 @@
  *
  * Private instance structure.
  */
-struct OstreeGpgVerifyResult {
+struct OstreeGpgVerifyResult
+{
   GObject parent;
 
   gpgme_ctx_t context;
