@@ -26,13 +26,13 @@
 #include "config.h"
 
 #include <gio/gio.h>
-#include <glib.h>
 #include <glib-object.h>
+#include <glib.h>
 #include <stdint.h>
 #include <string.h>
 
-#include "ostree-remote.h"
 #include "ostree-remote-private.h"
+#include "ostree-remote.h"
 #include "ot-keyfile-utils.h"
 
 /**
@@ -58,8 +58,7 @@ ostree_remote_new (const gchar *name)
 }
 
 OstreeRemote *
-ostree_remote_new_dynamic (const gchar *name,
-                           const gchar *refspec_name)
+ostree_remote_new_dynamic (const gchar *name, const gchar *refspec_name)
 {
   OstreeRemote *remote;
 
@@ -71,17 +70,17 @@ ostree_remote_new_dynamic (const gchar *name,
   remote->name = g_strdup (name);
   remote->refspec_name = g_strdup (refspec_name);
   remote->group = g_strdup_printf ("remote \"%s\"", (refspec_name != NULL) ? refspec_name : name);
-  remote->keyring = g_strdup_printf ("%s.trustedkeys.gpg", (refspec_name != NULL) ? refspec_name : name);
+  remote->keyring
+      = g_strdup_printf ("%s.trustedkeys.gpg", (refspec_name != NULL) ? refspec_name : name);
   remote->options = g_key_file_new ();
 
   return remote;
 }
 
 OstreeRemote *
-ostree_remote_new_from_keyfile (GKeyFile    *keyfile,
-                                const gchar *group)
+ostree_remote_new_from_keyfile (GKeyFile *keyfile, const gchar *group)
 {
-  g_autoptr(GMatchInfo) match = NULL;
+  g_autoptr (GMatchInfo) match = NULL;
   OstreeRemote *remote;
   g_autofree gchar *name = NULL;
 
@@ -156,9 +155,7 @@ ostree_remote_unref (OstreeRemote *remote)
     }
 }
 
-G_DEFINE_BOXED_TYPE(OstreeRemote, ostree_remote,
-                    ostree_remote_ref,
-                    ostree_remote_unref);
+G_DEFINE_BOXED_TYPE (OstreeRemote, ostree_remote, ostree_remote_ref, ostree_remote_unref);
 
 /**
  * ostree_remote_get_name:
@@ -186,7 +183,7 @@ ostree_remote_get_name (OstreeRemote *remote)
  *
  * Get the URL from the remote.
  *
- * Returns: (transfer full): the remote's URL
+ * Returns: (transfer full) (nullable): the remote's URL
  * Since: 2018.6
  */
 gchar *
