@@ -25,26 +25,19 @@
 
 G_BEGIN_DECLS
 
-GVariant *ot_gvariant_new_bytearray (const guchar   *data,
-                                     gsize           len);
+GVariant *ot_gvariant_new_bytearray (const guchar *data, gsize len);
 
 GVariant *ot_gvariant_new_ay_bytes (GBytes *bytes);
 
 GVariant *ot_gvariant_new_empty_string_dict (void);
 
-gboolean ot_variant_read_fd (int                  fd,
-                             goffset              offset,
-                             const GVariantType  *type,
-                             gboolean             trusted,
-                             GVariant           **out_variant,
-                             GError             **error);
+gboolean ot_variant_read_fd (int fd, goffset offset, const GVariantType *type, gboolean trusted,
+                             GVariant **out_variant, GError **error);
 
-GVariantBuilder *ot_util_variant_builder_from_variant (GVariant            *variant,
-                                                       const GVariantType  *type);
+GVariantBuilder *ot_util_variant_builder_from_variant (GVariant *variant, const GVariantType *type);
 
-gboolean
-ot_variant_bsearch_str (GVariant   *array,
-                        const char *str,
-                        int        *out_pos);
+gboolean ot_variant_bsearch_str (GVariant *array, const char *str, int *out_pos);
+
+const guint8 *ot_variant_get_data (GVariant *variant, GError **error);
 
 G_END_DECLS
