@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -28,7 +26,7 @@
 int
 main (int argc, char **argv)
 {
-  g_autoptr(GError) local_error = NULL;
+  g_autoptr (GError) local_error = NULL;
   GError **error = &local_error;
   GBytes *from_bytes = NULL;
   GBytes *to_bytes = NULL;
@@ -37,7 +35,8 @@ main (int argc, char **argv)
   OstreeRollsumMatches *matches;
   GMappedFile *mfile;
 
-  g_setenv ("GIO_USE_VFS", "local", TRUE);
+  gboolean is_ok = g_setenv ("GIO_USE_VFS", "local", TRUE);
+  g_assert (is_ok == TRUE);
 
   if (argc < 3)
     return 1;
@@ -58,12 +57,10 @@ main (int argc, char **argv)
 
   matches = _ostree_compute_rollsum_matches (from_bytes, to_bytes);
 
-  g_printerr ("rollsum crcs=%u bufs=%u total=%u matchsize=%llu\n",
-              matches->crcmatches,
-              matches->bufmatches,
-              matches->total, (unsigned long long)matches->match_size);
+  g_printerr ("rollsum crcs=%u bufs=%u total=%u matchsize=%llu\n", matches->crcmatches,
+              matches->bufmatches, matches->total, (unsigned long long)matches->match_size);
 
- out:
+out:
   if (local_error)
     {
       g_printerr ("%s\n", local_error->message);
