@@ -14,15 +14,13 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
 
-#include <stdlib.h>
 #include <gio/gio.h>
+#include <stdlib.h>
 #include <string.h>
 
 #include "libglnx.h"
@@ -42,8 +40,8 @@ run_sync (const char *cmdline, GError **error)
 static void
 test_sysroot_reload (gconstpointer data)
 {
-  OstreeSysroot *sysroot = (void*)data;
-  g_autoptr(GError) error = NULL;
+  OstreeSysroot *sysroot = (void *)data;
+  g_autoptr (GError) error = NULL;
   gboolean changed;
 
   if (!ostree_sysroot_load (sysroot, NULL, &error))
@@ -53,10 +51,14 @@ test_sysroot_reload (gconstpointer data)
     goto out;
   g_assert (!changed);
 
-  if (!run_sync ("ostree --repo=sysroot/ostree/repo pull-local --remote=testos testos-repo testos/buildmaster/x86_64-runtime", &error))
+  if (!run_sync ("ostree --repo=sysroot/ostree/repo pull-local --remote=testos testos-repo "
+                 "testos/buildmain/x86_64-runtime",
+                 &error))
     goto out;
 
-  if (!run_sync ("ostree admin --sysroot=sysroot deploy --karg=root=LABEL=MOO --karg=quiet --os=testos testos:testos/buildmaster/x86_64-runtime", &error))
+  if (!run_sync ("ostree admin --sysroot=sysroot deploy --karg=root=LABEL=MOO --karg=quiet "
+                 "--os=testos testos:testos/buildmain/x86_64-runtime",
+                 &error))
     goto out;
 
   if (!ostree_sysroot_load_if_changed (sysroot, &changed, NULL, &error))
@@ -67,26 +69,27 @@ test_sysroot_reload (gconstpointer data)
     goto out;
   g_assert (!changed);
 
- out:
+out:
   if (error)
     g_error ("%s", error->message);
 }
 
-int main (int argc, char **argv)
+int
+main (int argc, char **argv)
 {
-  g_autoptr(GError) error = NULL;
+  g_autoptr (GError) error = NULL;
   glnx_unref_object OstreeSysroot *sysroot = NULL;
 
   g_test_init (&argc, &argv, NULL);
 
-  sysroot = ot_test_setup_sysroot (NULL, &error); 
+  sysroot = ot_test_setup_sysroot (NULL, &error);
   if (!sysroot)
     goto out;
-  
+
   g_test_add_data_func ("/sysroot-reload", sysroot, test_sysroot_reload);
 
-  return g_test_run();
- out:
+  return g_test_run ();
+out:
   if (error)
     g_error ("%s", error->message);
   return 1;
