@@ -15,9 +15,7 @@
 // Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public
-// License along with this library; if not, write to the
-// Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// License along with this library. If not, see <https://www.gnu.org/licenses/>.
 
 const GLib = imports.gi.GLib;
 const Gio = imports.gi.Gio;
@@ -49,7 +47,7 @@ GLib.setenv("OSTREE_SYSROOT_DEBUG", "mutable-deployments", true);
 let upstreamRepo = OSTree.Repo.new(Gio.File.new_for_path('testos-repo'));
 upstreamRepo.open(null);
 
-let runtimeRef = 'testos/buildmaster/x86_64-runtime';
+let runtimeRef = 'testos/buildmain/x86_64-runtime';
 let [,rev] = upstreamRepo.resolve_rev(runtimeRef, false);
 
 print("testos => " + rev);
