@@ -15,9 +15,7 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# License along with this library. If not, see <https://www.gnu.org/licenses/>.
 
 set -euo pipefail
 
@@ -42,8 +40,8 @@ echo "ok commit with xattrs"
 
 ${CMD_PREFIX} ostree --repo=repo checkout test2 test2-checkout2
 getfattr -m . test2-checkout2/firstfile > attrs
-assert_file_has_content attrs '^user.ostree-test'
-assert_file_has_content attrs '^user.test0'
+assert_file_has_content attrs '^user\.ostree-test'
+assert_file_has_content attrs '^user\.test0'
 getfattr -n user.ostree-test --only-values test2-checkout2/firstfile > v0
 assert_file_has_content v0 '^testvalue$'
 getfattr -n user.test0 --only-values test2-checkout2/firstfile > v1
